import { EventEmitter, OnDestroy, OnInit, QueryList, TemplateRef } from '@angular/core';
import { DataTableColumn, DataTableHeaderEvent, DataTableRow, DataTableRowSelectEvent, DataTableTranslations, RowCallback } from '../../models';
import { DataTableColumnDirective } from '../../directives/column.directive';
import { DataTableRowComponent } from '../row/row.component';
import { DataTableTitleDirective } from '../../directives/title.directive';
import { DataTableStateService } from '../../services/data-table-state.service';
import * as i0 from "@angular/core";
export declare class DataTableComponent<T> implements OnInit, OnDestroy {
    state: DataTableStateService<T>;
    constructor(state: DataTableStateService<T>);
    private _resizeInProgress;
    private subscription;
    selectedRow: DataTableRow<T> | undefined;
    selectedRows: DataTableRow<T>[];
    resizeLimit: number;
    set itemCount(itemCount: number);
    set pagination(pagination: boolean);
    set indexColumn(indexColumn: boolean);
    indexColumnHeader: string;
    set rowColors(rowColors: RowCallback<T>);
    set rowTooltip(rowTooltip: RowCallback<T>);
    set selectColumn(selectColumn: boolean);
    multiSelect: boolean;
    substituteRows: boolean;
    set expandableRows(value: boolean);
    set translations(value: DataTableTranslations);
    set selectOnRowClick(value: boolean);
    autoReload: boolean;
    showReloading: boolean;
    rowClick: EventEmitter<import("../../models").DataTableRowEvent<T>>;
    rowExpand: EventEmitter<import("../../models").DataTableRowEvent<T>>;
    rowSelected: EventEmitter<DataTableRowSelectEvent<T>>;
    rowDoubleClick: EventEmitter<import("../../models").DataTableRowEvent<T>>;
    headerClick: EventEmitter<DataTableHeaderEvent<T>>;
    cellClick: EventEmitter<import("../../models").DataTableCellEvent<T>>;
    reload: EventEmitter<import("../../models").DataTableParams>;
    set title(value: DataTableTitleDirective);
    set columns(value: QueryList<DataTableColumnDirective<T>>);
    set rows(value: QueryList<DataTableRowComponent<T>>);
    set expandTemplate(value: TemplateRef<any>);
    set items(items: T[]);
    set sortBy(value: string);
    set sortAsc(value: boolean);
    set offset(value: number);
    set limit(value: number);
    set page(value: number);
    get substituteItems(): any[];
    headerClicked(column: DataTableColumn<T>, event: MouseEvent): void;
    onRowSelectChanged(row: DataTableRow<T>, event: MouseEvent): void;
    resizeColumnStart(event: MouseEvent, column: DataTableColumn<T>, columnElement: HTMLElement): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    private sortColumn;
    private sort;
    private isResizeInLimit;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataTableComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataTableComponent<any>, "data-table", never, { "itemCount": "itemCount"; "pagination": "pagination"; "indexColumn": "indexColumn"; "indexColumnHeader": "indexColumnHeader"; "rowColors": "rowColors"; "rowTooltip": "rowTooltip"; "selectColumn": "selectColumn"; "multiSelect": "multiSelect"; "substituteRows": "substituteRows"; "expandableRows": "expandableRows"; "translations": "translations"; "selectOnRowClick": "selectOnRowClick"; "autoReload": "autoReload"; "showReloading": "showReloading"; "items": "items"; "sortBy": "sortBy"; "sortAsc": "sortAsc"; "offset": "offset"; "limit": "limit"; "page": "page"; }, { "rowClick": "rowClick"; "rowExpand": "rowExpand"; "rowSelected": "rowSelected"; "rowDoubleClick": "rowDoubleClick"; "headerClick": "headerClick"; "cellClick": "cellClick"; "reload": "reload"; }, ["title", "expandTemplate", "columns"], never>;
}
