import * as i0 from '@angular/core';
import { Directive, Input, ContentChild, EventEmitter, Injectable, Component, Output, HostListener, Pipe, ViewEncapsulation, ContentChildren, ViewChildren, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { Subscription } from 'rxjs';

const defaultTranslations = {
    indexColumn: 'index',
    selectColumn: 'select',
    expandColumn: 'expand',
    paginationLimit: 'Limit',
    paginationRange: 'Results'
};

const drag = (event, { move, up }) => {
    const { pageX, pageY } = event;
    let x = pageX;
    let y = pageY;
    let moved = false;
    const mouseMoveHandler = (e) => {
        // tslint:disable-next-line:no-shadowed-variable
        const { pageX, pageY } = e;
        const dx = pageX - x;
        const dy = pageY - y;
        x = pageX;
        y = pageY;
        if (dx || dy) {
            moved = true;
        }
        move(e, dx, dy, x, y);
        e.preventDefault(); // to avoid text selection
    };
    const mouseUpHandler = (e) => {
        // tslint:disable-next-line:no-shadowed-variable
        const { pageX, pageY } = e;
        x = pageX;
        y = pageY;
        document.removeEventListener('mousemove', mouseMoveHandler);
        document.removeEventListener('mouseup', mouseUpHandler);
        if (up) {
            up(e, x, y, moved);
        }
    };
    document.addEventListener('mousemove', mouseMoveHandler);
    document.addEventListener('mouseup', mouseUpHandler);
};

class DataTableColumnDirective {
    constructor() {
        this.ngStyleClass = {};
        this.item = {};
        this.sortable = false;
        this.resizable = false;
        this.visible = true;
    }
    get cellColor() {
        return this.cellColors && this.cellColors(this) || '';
    }
    ngOnInit() {
        if (!this.styleClass && this.property) {
            if (/^[a-zA-Z0-9_]+$/.test(this.property)) {
                this.styleClass = 'column-' + this.property;
            }
            else {
                this.styleClass = 'column-' + this.property.replace(/[^a-zA-Z0-9_]/g, '');
            }
        }
        if (this.styleClass != null) {
            this.ngStyleClass = {
                [this.styleClass]: true
            };
        }
    }
}
DataTableColumnDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableColumnDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
DataTableColumnDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.0.2", type: DataTableColumnDirective, selector: "data-table-column", inputs: { header: "header", sortable: "sortable", resizable: "resizable", property: "property", styleClass: "styleClass", cellColors: "cellColors", width: "width", visible: "visible" }, queries: [{ propertyName: "cellTemplate", first: true, predicate: ["cellTemplate"], descendants: true }, { propertyName: "headerTemplate", first: true, predicate: ["headerTemplate"], descendants: true }], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'data-table-column'
                }]
        }], propDecorators: { header: [{
                type: Input
            }], sortable: [{
                type: Input
            }], resizable: [{
                type: Input
            }], property: [{
                type: Input
            }], styleClass: [{
                type: Input
            }], cellColors: [{
                type: Input
            }], width: [{
                type: Input
            }], visible: [{
                type: Input
            }], cellTemplate: [{
                type: ContentChild,
                args: ['cellTemplate']
            }], headerTemplate: [{
                type: ContentChild,
                args: ['headerTemplate']
            }] } });

class DataTableStateService {
    constructor() {
        this._scheduledReload = null;
        this._selectAllCheckbox = false;
        this._sortBy = '';
        this._sortAsc = true;
        this._reloading = false;
        this._items = [];
        this._limit = 10;
        this._offset = 0;
        this.translations = defaultTranslations;
        this.indexColumnVisible = false;
        this.indexColumn = true;
        this.selectColumnVisible = false;
        this.selectColumn = false;
        this.expandColumnVisible = false;
        this.expandableRows = false;
        this.selectOnRowClick = false;
        this.pagination = true;
        this.itemCount = 0;
        this.columns = [];
        this.reload = new EventEmitter();
        this.rowExpand = new EventEmitter();
        this.rowClick = new EventEmitter();
        this.rowDoubleClick = new EventEmitter();
        this.cellClick = new EventEmitter();
    }
    get items() {
        return this._items;
    }
    set items(items) {
        this._items = items;
        this._selectAllCheckbox = false;
        this._reloading = false;
    }
    get sortBy() {
        return this._sortBy;
    }
    set sortBy(value) {
        this._sortBy = value;
        this.triggerReload();
    }
    get sortAsc() {
        return this._sortAsc;
    }
    set sortAsc(value) {
        this._sortAsc = value;
        this.triggerReload();
    }
    get reloading() {
        return this._reloading;
    }
    get offset() {
        return this._offset;
    }
    set offset(value) {
        this._offset = value;
        this.triggerReload();
    }
    set limit(value) {
        this._limit = value;
        this.triggerReload();
    }
    get limit() {
        return this._limit;
    }
    get page() {
        return Math.floor(this.offset / this.limit) + 1;
    }
    set page(value) {
        this.offset = (value - 1) * this.limit;
        this.triggerReload();
    }
    get lastPage() {
        return Math.ceil(this.itemCount / this.limit);
    }
    reloadItems() {
        this._reloading = true;
        this.reload.emit(this.buildPaginationQuery());
    }
    buildPaginationQuery() {
        const params = {};
        if (this.sortBy) {
            params.sortBy = this.sortBy;
            params.sortAsc = this.sortAsc;
        }
        if (this.pagination) {
            params.offset = this.offset;
            params.limit = this.limit;
        }
        return params;
    }
    triggerReload() {
        // for avoiding cascading reloads if multiple params are set at once:
        if (this._scheduledReload) {
            clearTimeout(this._scheduledReload);
        }
        this._scheduledReload = setTimeout(() => {
            this.reloadItems();
        });
    }
    get selectAllCheckbox() {
        return this._selectAllCheckbox;
    }
    set selectAllCheckbox(value) {
        this._selectAllCheckbox = value;
        this.rows?.forEach(row => row.selected = value);
    }
}
DataTableStateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableStateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
DataTableStateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableStateService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableStateService, decorators: [{
            type: Injectable
        }] });

class DataTableRowComponent {
    constructor(state) {
        this.state = state;
        this._selected = false;
        this.expanded = false;
        this.item = {};
        this.index = 0;
        this.selectedChange = new EventEmitter();
    }
    get selected() {
        return this._selected;
    }
    set selected(selected) {
        this._selected = selected;
        this.selectedChange.emit(selected);
    }
    get displayIndex() {
        if (this.state.pagination) {
            return (this.state.offset || 0) + this.index + 1;
        }
        else {
            return this.index + 1;
        }
    }
    getTooltip() {
        return this.state.rowTooltip && this.state.rowTooltip(this) || '';
    }
    getContent(column) {
        return column.property && this.item[column.property] || '';
    }
    get columnCount() {
        let count = 0;
        count += this.state.indexColumnVisible ? 1 : 0;
        count += this.state.selectColumnVisible ? 1 : 0;
        count += this.state.expandColumnVisible ? 1 : 0;
        this.state.columns.forEach(column => {
            count += column.visible ? 1 : 0;
        });
        return count;
    }
    rowExpanded(event) {
        this.state.rowExpand.emit({ row: this, event });
    }
    cellClicked(column, event) {
        this.state.cellClick.emit({ cell: { ...this.toRow(), ...column }, event });
    }
    rowClicked(event) {
        this.state.rowClick.emit({ row: this.toRow(), event });
    }
    rowDoubleClicked(event) {
        this.state.rowDoubleClick.emit({ row: this.toRow(), event });
    }
    getRowColor() {
        return this.state.rowColors && this.state.rowColors(this.toRow()) || '';
    }
    toRow() {
        return {
            item: this.item,
            index: this.index,
            expanded: this.expanded,
            selected: this.selected
        };
    }
}
DataTableRowComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableRowComponent, deps: [{ token: DataTableStateService }], target: i0.ɵɵFactoryTarget.Component });
DataTableRowComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: DataTableRowComponent, selector: "[dataTableRow]", inputs: { item: "item", index: "index" }, outputs: { selectedChange: "selectedChange" }, ngImport: i0, template: "<tr class=\"data-table-row\"\n    [title]=\"getTooltip()\"\n    [style.background-color]=\"getRowColor()\"\n    [class.row-odd]=\"index % 2 === 0\"\n    [class.row-even]=\"index % 2 === 1\"\n    [class.selected]=\"selected\"\n    [class.clickable]=\"state.selectOnRowClick\"\n    (dblclick)=\"rowDoubleClicked($event)\"\n    (click)=\"rowClicked($event)\"\n    *ngIf=\"item\">\n  <td *ngIf=\"state.expandColumnVisible\" class=\"row-expand-button\"\n      (click)=\"expanded = !expanded; $event.stopPropagation(); rowExpanded($event)\">\n    <span class=\"fa {{expanded ? 'fa-arrow-circle-o-down' : 'fa-arrow-circle-o-right'}}\"></span>\n  </td>\n  <td *ngIf=\"state.indexColumnVisible\" class=\"index-column\" [textContent]=\"displayIndex\"></td>\n  <td *ngIf=\"state.selectColumnVisible\" class=\"select-column\">\n    <input type=\"checkbox\" [(ngModel)]=\"selected\"/>\n  </td>\n  <ng-container *ngFor=\"let column of state.columns\">\n    <td class=\"data-column\"\n        [ngClass]=\"column.ngStyleClass\"\n        [style.background-color]=\"column.cellColor\"\n        (click)=\"cellClicked(column, $event)\"\n        *ngIf=\"column.visible\">\n      <div *ngIf=\"!column.cellTemplate\" [textContent]=\"getContent(column)\"></div>\n      <ng-container *ngIf=\"column.cellTemplate\" [ngTemplateOutlet]=\"column.cellTemplate\"\n                    [ngTemplateOutletContext]=\"{column: column, row: toRow(), item: item}\"></ng-container>\n    </td>\n  </ng-container>\n</tr>\n<tr class=\"row-expansion {{expanded? '' : 'd-none'}}\"\n    *ngIf=\"state.expandableRows && expanded\">\n  <td [attr.colspan]=\"columnCount\">\n    <ng-container [ngTemplateOutlet]=\"state.expandTemplate\"\n                  [ngTemplateOutletContext]=\"{row: toRow(), item: item}\"\n                  *ngIf=\"state.expandTemplate\"></ng-container>\n  </td>\n</tr>\n", styles: [".select-column{text-align:center}.row-expand-button{cursor:pointer;text-align:center}.clickable{cursor:pointer}\n"], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableRowComponent, decorators: [{
            type: Component,
            args: [{ selector: '[dataTableRow]', template: "<tr class=\"data-table-row\"\n    [title]=\"getTooltip()\"\n    [style.background-color]=\"getRowColor()\"\n    [class.row-odd]=\"index % 2 === 0\"\n    [class.row-even]=\"index % 2 === 1\"\n    [class.selected]=\"selected\"\n    [class.clickable]=\"state.selectOnRowClick\"\n    (dblclick)=\"rowDoubleClicked($event)\"\n    (click)=\"rowClicked($event)\"\n    *ngIf=\"item\">\n  <td *ngIf=\"state.expandColumnVisible\" class=\"row-expand-button\"\n      (click)=\"expanded = !expanded; $event.stopPropagation(); rowExpanded($event)\">\n    <span class=\"fa {{expanded ? 'fa-arrow-circle-o-down' : 'fa-arrow-circle-o-right'}}\"></span>\n  </td>\n  <td *ngIf=\"state.indexColumnVisible\" class=\"index-column\" [textContent]=\"displayIndex\"></td>\n  <td *ngIf=\"state.selectColumnVisible\" class=\"select-column\">\n    <input type=\"checkbox\" [(ngModel)]=\"selected\"/>\n  </td>\n  <ng-container *ngFor=\"let column of state.columns\">\n    <td class=\"data-column\"\n        [ngClass]=\"column.ngStyleClass\"\n        [style.background-color]=\"column.cellColor\"\n        (click)=\"cellClicked(column, $event)\"\n        *ngIf=\"column.visible\">\n      <div *ngIf=\"!column.cellTemplate\" [textContent]=\"getContent(column)\"></div>\n      <ng-container *ngIf=\"column.cellTemplate\" [ngTemplateOutlet]=\"column.cellTemplate\"\n                    [ngTemplateOutletContext]=\"{column: column, row: toRow(), item: item}\"></ng-container>\n    </td>\n  </ng-container>\n</tr>\n<tr class=\"row-expansion {{expanded? '' : 'd-none'}}\"\n    *ngIf=\"state.expandableRows && expanded\">\n  <td [attr.colspan]=\"columnCount\">\n    <ng-container [ngTemplateOutlet]=\"state.expandTemplate\"\n                  [ngTemplateOutletContext]=\"{row: toRow(), item: item}\"\n                  *ngIf=\"state.expandTemplate\"></ng-container>\n  </td>\n</tr>\n", styles: [".select-column{text-align:center}.row-expand-button{cursor:pointer;text-align:center}.clickable{cursor:pointer}\n"] }]
        }], ctorParameters: function () { return [{ type: DataTableStateService }]; }, propDecorators: { item: [{
                type: Input
            }], index: [{
                type: Input
            }], selectedChange: [{
                type: Output
            }] } });

class DataTableTitleDirective {
    constructor() {
        this.title = '';
        this.controls = true;
    }
}
DataTableTitleDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
DataTableTitleDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.0.2", type: DataTableTitleDirective, selector: "data-table-title", inputs: { title: "title", controls: "controls" }, queries: [{ propertyName: "titleTemplate", first: true, predicate: ["titleTemplate"], descendants: true }], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'data-table-title'
                }]
        }], propDecorators: { title: [{
                type: Input
            }], titleTemplate: [{
                type: ContentChild,
                args: ['titleTemplate']
            }], controls: [{
                type: Input
            }] } });

class DataTableTitleComponent {
    constructor(state) {
        this.state = state;
        this.columnSelectorOpen = false;
    }
    closeSelector() {
        this.columnSelectorOpen = false;
    }
}
DataTableTitleComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableTitleComponent, deps: [{ token: DataTableStateService }], target: i0.ɵɵFactoryTarget.Component });
DataTableTitleComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: DataTableTitleComponent, selector: "table-title", inputs: { title: "title" }, host: { listeners: { "document:click": "closeSelector()" } }, ngImport: i0, template: "<div class=\"navbar\" *ngIf=\"state.title as titleRef\">\n  <h4 class=\"title\" [textContent]=\"titleRef.title\"></h4>\n  <ng-container [ngTemplateOutlet]=\"titleTemplate\"\n                [ngTemplateOutletContext]=\"{items: state.items}\"\n                *ngIf=\"titleRef.titleTemplate as titleTemplate\">\n  </ng-container>\n  <div *ngIf=\"titleRef.controls\">\n    <button type=\"button\" class=\"btn btn-default btn-sm refresh-button\"\n            (click)=\"state.reloadItems()\">\n      <i class=\"fa fa-refresh\"></i>\n    </button>\n    <button type=\"button\" class=\"btn btn-default btn-sm column-selector-button\"\n            [class.active]=\"columnSelectorOpen\"\n            (click)=\"columnSelectorOpen = !columnSelectorOpen; $event.stopPropagation()\">\n      <i class=\"fa fa-list\"></i>\n    </button>\n    <div class=\"column-selector-wrapper\" (click)=\"$event.stopPropagation()\">\n      <div *ngIf=\"columnSelectorOpen\" class=\"column-selector-box card\">\n        <div *ngIf=\"state.expandableRows\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.expandColumnVisible\"/>\n            <span>&nbsp;{{state.translations.expandColumn}}</span>\n        </div>\n        <div *ngIf=\"state.indexColumn\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.indexColumnVisible\"/>\n            <span>&nbsp;{{state.translations.indexColumn}}</span>\n        </div>\n        <div *ngIf=\"state.selectColumn\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.selectColumnVisible\"/>\n            <span>&nbsp;{{state.translations.selectColumn}}</span>\n        </div>\n        <div *ngFor=\"let column of state.columns\" class=\"column-selector-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"column.visible\"/>\n            <span>&nbsp;{{column.header}}</span>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: [".navbar{padding:10px 0}.navbar .title{margin:5px 0 0 5px}.navbar .column-selector-wrapper{position:relative}.navbar .column-selector-wrapper .column-selector-box{box-shadow:0 0 10px #d3d3d3;width:150px;padding:10px;position:absolute;right:0;top:1px;z-index:1060}.navbar .column-selector-wrapper .column-selector-box .checkbox{margin-bottom:4px}.navbar .column-selector-wrapper .column-selector-box .column-selector-fixed-column{font-style:italic}\n"], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }, { type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableTitleComponent, decorators: [{
            type: Component,
            args: [{ selector: 'table-title', template: "<div class=\"navbar\" *ngIf=\"state.title as titleRef\">\n  <h4 class=\"title\" [textContent]=\"titleRef.title\"></h4>\n  <ng-container [ngTemplateOutlet]=\"titleTemplate\"\n                [ngTemplateOutletContext]=\"{items: state.items}\"\n                *ngIf=\"titleRef.titleTemplate as titleTemplate\">\n  </ng-container>\n  <div *ngIf=\"titleRef.controls\">\n    <button type=\"button\" class=\"btn btn-default btn-sm refresh-button\"\n            (click)=\"state.reloadItems()\">\n      <i class=\"fa fa-refresh\"></i>\n    </button>\n    <button type=\"button\" class=\"btn btn-default btn-sm column-selector-button\"\n            [class.active]=\"columnSelectorOpen\"\n            (click)=\"columnSelectorOpen = !columnSelectorOpen; $event.stopPropagation()\">\n      <i class=\"fa fa-list\"></i>\n    </button>\n    <div class=\"column-selector-wrapper\" (click)=\"$event.stopPropagation()\">\n      <div *ngIf=\"columnSelectorOpen\" class=\"column-selector-box card\">\n        <div *ngIf=\"state.expandableRows\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.expandColumnVisible\"/>\n            <span>&nbsp;{{state.translations.expandColumn}}</span>\n        </div>\n        <div *ngIf=\"state.indexColumn\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.indexColumnVisible\"/>\n            <span>&nbsp;{{state.translations.indexColumn}}</span>\n        </div>\n        <div *ngIf=\"state.selectColumn\" class=\"column-selector-fixed-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"state.selectColumnVisible\"/>\n            <span>&nbsp;{{state.translations.selectColumn}}</span>\n        </div>\n        <div *ngFor=\"let column of state.columns\" class=\"column-selector-column checkbox\">\n            <input type=\"checkbox\" [(ngModel)]=\"column.visible\"/>\n            <span>&nbsp;{{column.header}}</span>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n", styles: [".navbar{padding:10px 0}.navbar .title{margin:5px 0 0 5px}.navbar .column-selector-wrapper{position:relative}.navbar .column-selector-wrapper .column-selector-box{box-shadow:0 0 10px #d3d3d3;width:150px;padding:10px;position:absolute;right:0;top:1px;z-index:1060}.navbar .column-selector-wrapper .column-selector-box .checkbox{margin-bottom:4px}.navbar .column-selector-wrapper .column-selector-box .column-selector-fixed-column{font-style:italic}\n"] }]
        }], ctorParameters: function () { return [{ type: DataTableStateService }]; }, propDecorators: { title: [{
                type: Input
            }], closeSelector: [{
                type: HostListener,
                args: ['document:click']
            }] } });

class MinPipe {
    transform(value) {
        return `${Math.min.apply(null, value)}`;
    }
}
MinPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: MinPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MinPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: MinPipe, name: "min" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: MinPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'min'
                }]
        }] });

class DataTablePaginationComponent {
    constructor(state) {
        this.state = state;
    }
    get maxPage() {
        return Math.ceil(this.state.itemCount / this.state.limit);
    }
    get limit() {
        return `${this.state.limit}`;
    }
    set limit(value) {
        if (Number(value) > 0) {
            this.state.limit = Math.floor(+value);
        }
    }
    get page() {
        return `${this.state.page}`;
    }
    set page(value) {
        if (Number(value) > 0) {
            this.state.page = Math.floor(+value);
        }
    }
    pageBack() {
        this.state.offset -= Math.min(this.state.limit, this.state.offset);
    }
    pageForward() {
        this.state.offset += this.state.limit;
    }
    pageFirst() {
        this.state.offset = 0;
    }
    pageLast() {
        this.state.offset = (this.maxPage - 1) * this.state.limit;
    }
    keyPress(event) {
        if (!(Number(event.key) >= 0)) {
            event.preventDefault();
        }
    }
}
DataTablePaginationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTablePaginationComponent, deps: [{ token: DataTableStateService }], target: i0.ɵɵFactoryTarget.Component });
DataTablePaginationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: DataTablePaginationComponent, selector: "table-pagination", ngImport: i0, template: "<div class=\"navbar p-0 pagination-component\">\n  <div>\n    {{state.translations.paginationRange}}:&nbsp;{{state.offset < 0 ? 0 : state.offset + 1}}&nbsp;-\n    {{[state.offset + state.limit , state.itemCount] | min}}&nbsp;/&nbsp;{{state.itemCount}}\n  </div>\n  <ul class=\"nav justify-content-end\">\n    <li class=\"nav-item pagination-limit\">\n      <div class=\"input-group\">\n        <div class=\"input-group-prepend\">\n          <span class=\"input-group-text\">{{state.translations.paginationLimit}}:</span>\n        </div>\n        <input #limitInput type=\"number\" class=\"form-control\" min=\"1\" step=\"1\"\n               [ngModel]=\"limit\" (blur)=\"limit = limitInput.value\"\n               (keyup.enter)=\"limit = limitInput.value\"\n               (keyup.esc)=\"limitInput.value = limit\"\n               (keypress)=\"keyPress($event)\"/>\n      </div>\n    </li>\n    <li class=\"nav-item\">\n      <button [disabled]=\"state.offset <= 0\" (click)=\"pageFirst()\" class=\"btn btn-default\">&laquo;</button>\n      <button [disabled]=\"state.offset <= 0\" (click)=\"pageBack()\" class=\"btn btn-default\">&lsaquo;</button>\n      <div class=\"d-inline-block\">\n        <div class=\"input-group\">\n          <input #pageInput type=\"number\" class=\"form-control\" min=\"1\" step=\"1\" max=\"{{maxPage}}\"\n                 [ngModel]=\"page\" (blur)=\"page = pageInput.value\"\n                 (keyup.enter)=\"page = pageInput.value\" (keyup.esc)=\"pageInput.value = page\"\n                 (keypress)=\"keyPress($event)\"/>\n          <div class=\"input-group-append\">\n            <span class=\"input-group-text\">/&nbsp;{{state.lastPage}}</span>\n          </div>\n        </div>\n      </div>\n      <button [disabled]=\"(state.offset + state.limit) >= state.itemCount\" (click)=\"pageForward()\"\n              class=\"btn btn-default\">&rsaquo;\n      </button>\n      <button [disabled]=\"(state.offset + state.limit) >= state.itemCount\" (click)=\"pageLast()\"\n              class=\"btn btn-default\">&raquo;\n      </button>\n    </li>\n  </ul>\n</div>\n", styles: [".pagination-component .pagination-limit{margin-right:1rem}.pagination-component .pagination-limit input{width:75px}.pagination-component .btn{margin-top:-3px}\n"], directives: [{ type: i3.MinValidator, selector: "input[type=number][min][formControlName],input[type=number][min][formControl],input[type=number][min][ngModel]", inputs: ["min"] }, { type: i3.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i3.MaxValidator, selector: "input[type=number][max][formControlName],input[type=number][max][formControl],input[type=number][max][ngModel]", inputs: ["max"] }], pipes: { "min": MinPipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTablePaginationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'table-pagination', template: "<div class=\"navbar p-0 pagination-component\">\n  <div>\n    {{state.translations.paginationRange}}:&nbsp;{{state.offset < 0 ? 0 : state.offset + 1}}&nbsp;-\n    {{[state.offset + state.limit , state.itemCount] | min}}&nbsp;/&nbsp;{{state.itemCount}}\n  </div>\n  <ul class=\"nav justify-content-end\">\n    <li class=\"nav-item pagination-limit\">\n      <div class=\"input-group\">\n        <div class=\"input-group-prepend\">\n          <span class=\"input-group-text\">{{state.translations.paginationLimit}}:</span>\n        </div>\n        <input #limitInput type=\"number\" class=\"form-control\" min=\"1\" step=\"1\"\n               [ngModel]=\"limit\" (blur)=\"limit = limitInput.value\"\n               (keyup.enter)=\"limit = limitInput.value\"\n               (keyup.esc)=\"limitInput.value = limit\"\n               (keypress)=\"keyPress($event)\"/>\n      </div>\n    </li>\n    <li class=\"nav-item\">\n      <button [disabled]=\"state.offset <= 0\" (click)=\"pageFirst()\" class=\"btn btn-default\">&laquo;</button>\n      <button [disabled]=\"state.offset <= 0\" (click)=\"pageBack()\" class=\"btn btn-default\">&lsaquo;</button>\n      <div class=\"d-inline-block\">\n        <div class=\"input-group\">\n          <input #pageInput type=\"number\" class=\"form-control\" min=\"1\" step=\"1\" max=\"{{maxPage}}\"\n                 [ngModel]=\"page\" (blur)=\"page = pageInput.value\"\n                 (keyup.enter)=\"page = pageInput.value\" (keyup.esc)=\"pageInput.value = page\"\n                 (keypress)=\"keyPress($event)\"/>\n          <div class=\"input-group-append\">\n            <span class=\"input-group-text\">/&nbsp;{{state.lastPage}}</span>\n          </div>\n        </div>\n      </div>\n      <button [disabled]=\"(state.offset + state.limit) >= state.itemCount\" (click)=\"pageForward()\"\n              class=\"btn btn-default\">&rsaquo;\n      </button>\n      <button [disabled]=\"(state.offset + state.limit) >= state.itemCount\" (click)=\"pageLast()\"\n              class=\"btn btn-default\">&raquo;\n      </button>\n    </li>\n  </ul>\n</div>\n", styles: [".pagination-component .pagination-limit{margin-right:1rem}.pagination-component .pagination-limit input{width:75px}.pagination-component .btn{margin-top:-3px}\n"] }]
        }], ctorParameters: function () { return [{ type: DataTableStateService }]; } });

class PxPipe {
    transform(value, ...args) {
        return value && Number(value) >= 0 && `${value}px` || `${value}`;
    }
}
PxPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: PxPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
PxPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: PxPipe, name: "px" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: PxPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'px'
                }]
        }] });

class DataTableComponent {
    constructor(state) {
        this.state = state;
        this._resizeInProgress = false;
        this.subscription = new Subscription();
        this.selectedRows = [];
        this.resizeLimit = 30;
        this.indexColumnHeader = '';
        this.multiSelect = true;
        this.substituteRows = true;
        this.autoReload = true;
        this.showReloading = false;
        // event handlers:
        this.rowClick = this.state.rowClick;
        this.rowExpand = this.state.rowExpand;
        this.rowSelected = new EventEmitter();
        this.rowDoubleClick = this.state.rowDoubleClick;
        this.headerClick = new EventEmitter();
        this.cellClick = this.state.cellClick;
        this.reload = this.state.reload;
    }
    set itemCount(itemCount) {
        this.state.itemCount = itemCount;
    }
    set pagination(pagination) {
        this.state.pagination = pagination;
    }
    set indexColumn(indexColumn) {
        this.state.indexColumn = indexColumn;
    }
    set rowColors(rowColors) {
        this.state.rowColors = rowColors;
    }
    set rowTooltip(rowTooltip) {
        this.state.rowTooltip = rowTooltip;
    }
    set selectColumn(selectColumn) {
        this.state.selectColumn = selectColumn;
    }
    set expandableRows(value) {
        this.state.expandableRows = value;
    }
    set translations(value) {
        this.state.translations = value;
    }
    set selectOnRowClick(value) {
        this.state.selectOnRowClick = value;
    }
    // UI components:
    set title(value) {
        this.state.title = value;
    }
    set columns(value) {
        this.state.columns = value.toArray();
    }
    set rows(value) {
        this.state.rows = value.toArray();
    }
    set expandTemplate(value) {
        this.state.expandTemplate = value;
    }
    set items(items) {
        this.state.items = items;
    }
    set sortBy(value) {
        this.state.sortBy = value;
    }
    set sortAsc(value) {
        this.state.sortAsc = value;
    }
    set offset(value) {
        this.state.offset = value;
    }
    set limit(value) {
        this.state.limit = value;
    }
    set page(value) {
        this.state.page = value;
    }
    get substituteItems() {
        return Array.from({ length: this.state.limit - this.state.items.length });
    }
    headerClicked(column, event) {
        if (!this._resizeInProgress) {
            this.headerClick.emit({ column, event });
        }
        else {
            // this is because I can't prevent click from mouseup of the drag end
            this._resizeInProgress = false;
        }
    }
    onRowSelectChanged(row, event) {
        // maintain the selectedRow(s) view
        if (this.multiSelect) {
            const index = this.selectedRows.indexOf(row);
            if (row.selected && index < 0) {
                this.selectedRows.push(row);
            }
            else if (!row.selected && index >= 0) {
                this.selectedRows.splice(index, 1);
            }
        }
        else {
            if (row.selected) {
                this.selectedRow = row;
            }
            else if (this.selectedRow === row) {
                this.selectedRow = undefined;
            }
            this.selectedRows = this.selectedRow && [this.selectedRow] || [];
        }
        this.rowSelected.emit({ rows: this.selectedRows, event });
        // unselect all other rows:
        if (row.selected && !this.multiSelect) {
            this.state.rows?.filter(r => r.selected).forEach(r => {
                if (r !== row) { // avoid endless loop
                    r.selected = false;
                }
            });
        }
    }
    resizeColumnStart(event, column, columnElement) {
        this._resizeInProgress = true;
        drag(event, {
            move: (moveEvent, dx) => {
                if (this.isResizeInLimit(columnElement, dx)) {
                    column.width = columnElement.offsetWidth + dx;
                }
            },
        });
    }
    ngOnInit() {
        this.state.indexColumnVisible = this.state.indexColumn;
        this.state.selectColumnVisible = this.state.selectColumn;
        this.state.expandColumnVisible = this.state.expandableRows;
        this.subscription.add(this.headerClick.subscribe(tableEvent => this.sortColumn(tableEvent.column)));
        if (this.state.selectOnRowClick) {
            this.subscription.add(this.state.rowClick.subscribe(tableEvent => {
                if (tableEvent.row) {
                    tableEvent.row.selected = !tableEvent.row.selected;
                }
            }));
        }
        this.autoReload && this.state.reloadItems();
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    sortColumn(column) {
        if (column && column.sortable) {
            const ascending = this.state.sortBy === column.property ? !this.state.sortAsc : true;
            column.property && this.sort(column.property, ascending);
        }
    }
    sort(sortBy, asc) {
        this.state.sortBy = sortBy;
        this.state.sortAsc = asc;
    }
    isResizeInLimit(columnElement, dx) {
        /* This is needed because CSS min-width didn't work on table-layout: fixed.
         Without the limits, resizing can make the next column disappear completely,
         and even increase the table width. The current implementation suffers from the fact,
         that offsetWidth sometimes contains out-of-date values. */
        return !((dx < 0 && (columnElement.offsetWidth + dx) <= this.resizeLimit) ||
            !columnElement.nextElementSibling || // resizing doesn't make sense for the last visible column
            (dx >= 0 && (columnElement.nextElementSibling.offsetWidth + dx) <= this.resizeLimit));
    }
}
DataTableComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableComponent, deps: [{ token: DataTableStateService }], target: i0.ɵɵFactoryTarget.Component });
DataTableComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: DataTableComponent, selector: "data-table", inputs: { itemCount: "itemCount", pagination: "pagination", indexColumn: "indexColumn", indexColumnHeader: "indexColumnHeader", rowColors: "rowColors", rowTooltip: "rowTooltip", selectColumn: "selectColumn", multiSelect: "multiSelect", substituteRows: "substituteRows", expandableRows: "expandableRows", translations: "translations", selectOnRowClick: "selectOnRowClick", autoReload: "autoReload", showReloading: "showReloading", items: "items", sortBy: "sortBy", sortAsc: "sortAsc", offset: "offset", limit: "limit", page: "page" }, outputs: { rowClick: "rowClick", rowExpand: "rowExpand", rowSelected: "rowSelected", rowDoubleClick: "rowDoubleClick", headerClick: "headerClick", cellClick: "cellClick", reload: "reload" }, providers: [DataTableStateService], queries: [{ propertyName: "title", first: true, predicate: DataTableTitleDirective, descendants: true }, { propertyName: "expandTemplate", first: true, predicate: ["expandTemplate"], descendants: true }, { propertyName: "columns", predicate: DataTableColumnDirective }], viewQueries: [{ propertyName: "rows", predicate: DataTableRowComponent, descendants: true }], ngImport: i0, template: "<table-title *ngIf=\"state.title\"></table-title>\n<div class=\"position-relative\">\n  <table class=\"table table-condensed data-table\">\n    <thead>\n    <tr>\n      <th class=\"expand-column-header\" *ngIf=\"state.expandColumnVisible\">\n      <th class=\"index-column-header\" *ngIf=\"state.indexColumnVisible\">\n        <span [textContent]=\"indexColumnHeader\"></span>\n      </th>\n      <th class=\"select-column-header\" *ngIf=\"state.selectColumnVisible\">\n        <input type=\"checkbox\" [(ngModel)]=\"state.selectAllCheckbox\" *ngIf=\"multiSelect\"/>\n      </th>\n      <ng-container *ngFor=\"let column of state.columns\">\n        <th class=\"column-header\"\n            #th\n            (click)=\"headerClicked(column, $event)\"\n            [class.sortable]=\"column.sortable\"\n            [class.resizable]=\"column.resizable\"\n            [ngClass]=\"column.ngStyleClass\"\n            [style.width]=\"column.width | px\"\n            *ngIf=\"column.visible\">\n          <span *ngIf=\"!column.headerTemplate\" [textContent]=\"column.header\"></span>\n          <ng-container *ngIf=\"column.headerTemplate\" [ngTemplateOutlet]=\"column.headerTemplate\"\n                        [ngTemplateOutletContext]=\"{column: column}\"></ng-container>\n          <span class=\"column-sort-icon\" *ngIf=\"column.sortable\">\n            <i class=\"fa fa-sort column-sortable-icon\" *ngIf=\"column.property !== state.sortBy else sortByTemplate\"></i>\n            <ng-template #sortByTemplate>\n              <i class=\"fa {{state.sortAsc ? 'fa-sort-desc' : 'fa-sort-asc'}}\"></i>\n            </ng-template>\n          </span>\n          <span *ngIf=\"column.resizable\" class=\"column-resize-handle\"\n                (mousedown)=\"resizeColumnStart($event, column, th)\"></span>\n        </th>\n      </ng-container>\n    </tr>\n    </thead>\n    <tbody #row\n           dataTableRow\n           [item]=\"item\"\n           [index]=\"index\"\n           (selectedChange)=\"onRowSelectChanged(row, $event)\"\n           *ngFor=\"let item of state.items; let index=index\">\n    </tbody>\n    <tbody *ngIf=\"state.pagination && substituteRows\">\n    <tr [class.row-odd]=\"(index + state.items.length) % 2 === 0\"\n        [class.row-even]=\"(index + state.items.length) % 2 === 1\"\n        *ngFor=\"let item of substituteItems, let index = index\">\n      <td *ngIf=\"state.expandColumnVisible\"></td>\n      <td *ngIf=\"state.indexColumnVisible\">&nbsp;</td>\n      <td *ngIf=\"state.selectColumnVisible\"></td>\n      <ng-container *ngFor=\"let column of state.columns\">\n        <td *ngIf=\"column.visible\">\n      </ng-container>\n    </tr>\n    </tbody>\n  </table>\n  <div class=\"loading-cover\" *ngIf=\"showReloading && state.reloading\"></div>\n</div>\n<table-pagination *ngIf=\"state.pagination\"></table-pagination>\n", styles: [".data-table{box-shadow:0 0 15px #ececec;table-layout:fixed}.data-table td{vertical-align:middle}.data-table thead>tr>th,.data-table tbody>tr>td{overflow:hidden}.data-table>tbody+tbody{border-top:none}.data-table .row-odd{background-color:#f6f6f6}.data-table .expand-column-header{width:50px}.data-table .select-column-header{width:50px;text-align:center}.data-table .index-column-header{width:40px}.data-table .column-header{position:relative}.data-table .column-header.sortable{cursor:pointer}.data-table .column-header.resizable{margin-right:8px}.data-table .column-header .column-sort-icon{float:right;margin-right:8px}.data-table .column-header .column-sort-icon .column-sortable-icon{color:#d3d3d3}.data-table .column-header .column-resize-handle{position:absolute;top:0;right:0;margin:0;padding:0;width:8px;height:100%;cursor:col-resize}.loading-cover{position:absolute;width:100%;height:100%;background-color:#ffffff4d;top:0}\n"], components: [{ type: DataTableTitleComponent, selector: "table-title", inputs: ["title"] }, { type: DataTableRowComponent, selector: "[dataTableRow]", inputs: ["item", "index"], outputs: ["selectedChange"] }, { type: DataTablePaginationComponent, selector: "table-pagination" }], directives: [{ type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i3.CheckboxControlValueAccessor, selector: "input[type=checkbox][formControlName],input[type=checkbox][formControl],input[type=checkbox][ngModel]" }, { type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }], pipes: { "px": PxPipe }, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'data-table', encapsulation: ViewEncapsulation.None, providers: [DataTableStateService], template: "<table-title *ngIf=\"state.title\"></table-title>\n<div class=\"position-relative\">\n  <table class=\"table table-condensed data-table\">\n    <thead>\n    <tr>\n      <th class=\"expand-column-header\" *ngIf=\"state.expandColumnVisible\">\n      <th class=\"index-column-header\" *ngIf=\"state.indexColumnVisible\">\n        <span [textContent]=\"indexColumnHeader\"></span>\n      </th>\n      <th class=\"select-column-header\" *ngIf=\"state.selectColumnVisible\">\n        <input type=\"checkbox\" [(ngModel)]=\"state.selectAllCheckbox\" *ngIf=\"multiSelect\"/>\n      </th>\n      <ng-container *ngFor=\"let column of state.columns\">\n        <th class=\"column-header\"\n            #th\n            (click)=\"headerClicked(column, $event)\"\n            [class.sortable]=\"column.sortable\"\n            [class.resizable]=\"column.resizable\"\n            [ngClass]=\"column.ngStyleClass\"\n            [style.width]=\"column.width | px\"\n            *ngIf=\"column.visible\">\n          <span *ngIf=\"!column.headerTemplate\" [textContent]=\"column.header\"></span>\n          <ng-container *ngIf=\"column.headerTemplate\" [ngTemplateOutlet]=\"column.headerTemplate\"\n                        [ngTemplateOutletContext]=\"{column: column}\"></ng-container>\n          <span class=\"column-sort-icon\" *ngIf=\"column.sortable\">\n            <i class=\"fa fa-sort column-sortable-icon\" *ngIf=\"column.property !== state.sortBy else sortByTemplate\"></i>\n            <ng-template #sortByTemplate>\n              <i class=\"fa {{state.sortAsc ? 'fa-sort-desc' : 'fa-sort-asc'}}\"></i>\n            </ng-template>\n          </span>\n          <span *ngIf=\"column.resizable\" class=\"column-resize-handle\"\n                (mousedown)=\"resizeColumnStart($event, column, th)\"></span>\n        </th>\n      </ng-container>\n    </tr>\n    </thead>\n    <tbody #row\n           dataTableRow\n           [item]=\"item\"\n           [index]=\"index\"\n           (selectedChange)=\"onRowSelectChanged(row, $event)\"\n           *ngFor=\"let item of state.items; let index=index\">\n    </tbody>\n    <tbody *ngIf=\"state.pagination && substituteRows\">\n    <tr [class.row-odd]=\"(index + state.items.length) % 2 === 0\"\n        [class.row-even]=\"(index + state.items.length) % 2 === 1\"\n        *ngFor=\"let item of substituteItems, let index = index\">\n      <td *ngIf=\"state.expandColumnVisible\"></td>\n      <td *ngIf=\"state.indexColumnVisible\">&nbsp;</td>\n      <td *ngIf=\"state.selectColumnVisible\"></td>\n      <ng-container *ngFor=\"let column of state.columns\">\n        <td *ngIf=\"column.visible\">\n      </ng-container>\n    </tr>\n    </tbody>\n  </table>\n  <div class=\"loading-cover\" *ngIf=\"showReloading && state.reloading\"></div>\n</div>\n<table-pagination *ngIf=\"state.pagination\"></table-pagination>\n", styles: [".data-table{box-shadow:0 0 15px #ececec;table-layout:fixed}.data-table td{vertical-align:middle}.data-table thead>tr>th,.data-table tbody>tr>td{overflow:hidden}.data-table>tbody+tbody{border-top:none}.data-table .row-odd{background-color:#f6f6f6}.data-table .expand-column-header{width:50px}.data-table .select-column-header{width:50px;text-align:center}.data-table .index-column-header{width:40px}.data-table .column-header{position:relative}.data-table .column-header.sortable{cursor:pointer}.data-table .column-header.resizable{margin-right:8px}.data-table .column-header .column-sort-icon{float:right;margin-right:8px}.data-table .column-header .column-sort-icon .column-sortable-icon{color:#d3d3d3}.data-table .column-header .column-resize-handle{position:absolute;top:0;right:0;margin:0;padding:0;width:8px;height:100%;cursor:col-resize}.loading-cover{position:absolute;width:100%;height:100%;background-color:#ffffff4d;top:0}\n"] }]
        }], ctorParameters: function () { return [{ type: DataTableStateService }]; }, propDecorators: { itemCount: [{
                type: Input
            }], pagination: [{
                type: Input
            }], indexColumn: [{
                type: Input
            }], indexColumnHeader: [{
                type: Input
            }], rowColors: [{
                type: Input
            }], rowTooltip: [{
                type: Input
            }], selectColumn: [{
                type: Input
            }], multiSelect: [{
                type: Input
            }], substituteRows: [{
                type: Input
            }], expandableRows: [{
                type: Input
            }], translations: [{
                type: Input
            }], selectOnRowClick: [{
                type: Input
            }], autoReload: [{
                type: Input
            }], showReloading: [{
                type: Input
            }], rowClick: [{
                type: Output
            }], rowExpand: [{
                type: Output
            }], rowSelected: [{
                type: Output
            }], rowDoubleClick: [{
                type: Output
            }], headerClick: [{
                type: Output
            }], cellClick: [{
                type: Output
            }], reload: [{
                type: Output
            }], title: [{
                type: ContentChild,
                args: [DataTableTitleDirective]
            }], columns: [{
                type: ContentChildren,
                args: [DataTableColumnDirective]
            }], rows: [{
                type: ViewChildren,
                args: [DataTableRowComponent]
            }], expandTemplate: [{
                type: ContentChild,
                args: ['expandTemplate']
            }], items: [{
                type: Input
            }], sortBy: [{
                type: Input
            }], sortAsc: [{
                type: Input
            }], offset: [{
                type: Input
            }], limit: [{
                type: Input
            }], page: [{
                type: Input
            }] } });

class DataTableResource {
    constructor(items) {
        this.items = items;
    }
    query(params, filter) {
        let result = [];
        if (filter) {
            result = this.items.filter(filter);
        }
        else {
            result = this.items.slice(); // shallow copy to use for sorting instead of changing the original
        }
        if (params.sortBy) {
            result.sort((a, b) => {
                if (params.sortBy) {
                    return typeof a[params.sortBy] === 'string' && a[params.sortBy].localeCompare(b[params.sortBy]) || a[params.sortBy] - b[params.sortBy];
                }
            });
            if (params.sortAsc === false) {
                result.reverse();
            }
        }
        if (params.offset !== undefined) { //cuz it's number but can be undefined
            result = params.limit !== undefined && result.slice(params.offset, params.offset + params.limit) || result.slice(params.offset, result.length);
        }
        return new Promise((resolve, reject) => {
            setTimeout(() => resolve(result));
        });
    }
    count() {
        return new Promise((resolve, reject) => {
            setTimeout(() => resolve(this.items.length));
        });
    }
}

class DataTableModule {
}
DataTableModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DataTableModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableModule, declarations: [DataTableComponent,
        DataTableTitleComponent,
        DataTableRowComponent,
        DataTablePaginationComponent,
        DataTableColumnDirective,
        DataTableTitleDirective,
        MinPipe,
        PxPipe], imports: [CommonModule,
        FormsModule], exports: [DataTableComponent,
        DataTableColumnDirective,
        DataTableTitleDirective] });
DataTableModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableModule, imports: [[
            CommonModule,
            FormsModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: DataTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule
                    ],
                    declarations: [
                        DataTableComponent,
                        DataTableTitleComponent,
                        DataTableRowComponent,
                        DataTablePaginationComponent,
                        DataTableColumnDirective,
                        DataTableTitleDirective,
                        MinPipe,
                        PxPipe,
                    ],
                    exports: [
                        DataTableComponent,
                        DataTableColumnDirective,
                        DataTableTitleDirective
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DataTableColumnDirective, DataTableComponent, DataTableModule, DataTableResource, DataTableTitleDirective, defaultTranslations };
//# sourceMappingURL=ngx-datatable-bootstrap4.mjs.map
