export interface DataTableParams {
    offset?: number;
    limit?: number;
    sortBy?: string;
    sortAsc?: boolean;
}
export interface DataTableTitle {
    title?: string;
    titleTemplate?: any;
    controls?: boolean;
}
export interface DataTableRow<T> extends Record<string, any> {
    item: T;
    index?: number;
    selected?: boolean;
    expanded?: boolean;
    visible?: boolean;
}
export interface DataTableColumn<T> extends DataTableRow<T> {
    sortable?: boolean;
    property?: string;
    width?: string | number;
    header?: string;
}
export declare type RowCallback<T> = (row: DataTableRow<T>) => string;
export declare type CellCallback<T> = (cell: DataTableColumn<T>) => string;
export interface DataTableTranslations {
    indexColumn: string;
    selectColumn: string;
    expandColumn: string;
    paginationLimit: string;
    paginationRange: string;
}
export declare const defaultTranslations: DataTableTranslations;
export interface DataTableEvent {
    event: MouseEvent;
}
export interface DataTableRowSelectEvent<T> extends DataTableEvent {
    rows: DataTableRow<T>[];
}
export interface DataTableRowEvent<T> extends DataTableEvent {
    row: DataTableRow<T>;
}
export interface DataTableCellEvent<T> extends DataTableEvent {
    cell: DataTableColumn<T>;
}
export interface DataTableHeaderEvent<T> extends DataTableEvent {
    column: DataTableColumn<T>;
}
